﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using ProjectDumpTruck.Entities;

namespace ProjectDumpTruck.Drawnings;

/// <summary>
/// Класс, отвечающий за прорисовку и перемещение объекта-сущности
/// </summary>
public class DrawningDumpTruck : DrawningTruck
{
    /// <summary>
    /// Консруктор
    /// </summary>
    /// <param name="speed">Скорость</param>
    /// <param name="weight">Вес</param>
    /// <param name="bodyColor">Основной цвет</param>
    /// <param name="additionalColor">Дополнительный цвет</param>
    /// <param name="bodywork">Признак наличия кузова</param>
    /// <param name="awning">Признак наличия тента</param>

    public DrawningDumpTruck(int speed, double weight, Color bodyColor, Color additionalColor, bool bodywork, bool awning) : base(130, 90)
    {
        EntityTruck = new EntityDumpTruck(speed, weight, bodyColor, additionalColor, bodywork, awning);
    }

    public override void DrawTransport(Graphics g)
    {
        if (EntityTruck == null || EntityTruck is not EntityDumpTruck dumpTruck || !_startPosX.HasValue || !_startPosY.HasValue)
        {
            return;
        }

        Pen pen = new(Color.Black);
        Brush additionalBrush = new SolidBrush(dumpTruck.AdditionalColor);
        Brush border = new SolidBrush(Color.Black);

        //Отрисовка кузова
        if (dumpTruck.Bodywork)
        {
            g.FillRectangle(additionalBrush, _startPosX.Value, _startPosY.Value, 90, 35);
        }

        _startPosX += 0;
        _startPosY += 0;
        base.DrawTransport(g);
        _startPosX -= 0;
        _startPosY -= 0;


        //Отрисовка тента
        if (dumpTruck.Bodywork & dumpTruck.Awning)
        {
            g.FillRectangle(border, _startPosX.Value, _startPosY.Value, 95, 10);
            g.FillRectangle(border, _startPosX.Value, _startPosY.Value, 95, 3);
            g.FillRectangle(border, _startPosX.Value + 30, _startPosY.Value, 3, 40);
            g.FillRectangle(border, _startPosX.Value + 70, _startPosY.Value, 3, 40);
        }
    }    
}